control_style library
Applies additional appearance settings to Flutter text fields, buttons and other controls.
Live example astoniocom.github.io
Classes
- DecoratedInputBorder
- Applies additional decoration to an InputBorder.
- DecoratedOutlinedBorder
- Applies additional decoration to an OutlinedBorder.
- GradientBorderSide
- A side of a border of a box that is painted with a gradient instead of a single color.
- GradientShadow
- A shadow cast by a box that is filled with a gradient instead of a single color.
Mixins
- DecorationPainter
- Extends functionality of standard Flutter's ShapeBorder with additional decoration.